from sraverify.services.waf.checks.sra_waf_01 import SRA_WAF_01
from sraverify.services.waf.checks.sra_waf_02 import SRA_WAF_02
from sraverify.services.waf.checks.sra_waf_03 import SRA_WAF_03
from sraverify.services.waf.checks.sra_waf_04 import SRA_WAF_04
from sraverify.services.waf.checks.sra_waf_05 import SRA_WAF_05
from sraverify.services.waf.checks.sra_waf_06 import SRA_WAF_06
from sraverify.services.waf.checks.sra_waf_07 import SRA_WAF_07
from sraverify.services.waf.checks.sra_waf_08 import SRA_WAF_08
from sraverify.services.waf.checks.sra_waf_09 import SRA_WAF_09

CHECKS = {
    "SRA-WAF-01": SRA_WAF_01,
    "SRA-WAF-02": SRA_WAF_02,
    "SRA-WAF-03": SRA_WAF_03,
    "SRA-WAF-04": SRA_WAF_04,
    "SRA-WAF-05": SRA_WAF_05,
    "SRA-WAF-06": SRA_WAF_06,
    "SRA-WAF-07": SRA_WAF_07,
    "SRA-WAF-08": SRA_WAF_08,
    "SRA-WAF-09": SRA_WAF_09,
}
