from sraverify.services.firewallmanager.checks.sra_firewallmanager_01 import SRA_FIREWALLMANAGER_01
from sraverify.services.firewallmanager.checks.sra_firewallmanager_02 import SRA_FIREWALLMANAGER_02
from sraverify.services.firewallmanager.checks.sra_firewallmanager_03 import SRA_FIREWALLMANAGER_03
from sraverify.services.firewallmanager.checks.sra_firewallmanager_04 import SRA_FIREWALLMANAGER_04
from sraverify.services.firewallmanager.checks.sra_firewallmanager_05 import SRA_FIREWALLMANAGER_05
from sraverify.services.firewallmanager.checks.sra_firewallmanager_06 import SRA_FIREWALLMANAGER_06
from sraverify.services.firewallmanager.checks.sra_firewallmanager_07 import SRA_FIREWALLMANAGER_07
from sraverify.services.firewallmanager.checks.sra_firewallmanager_08 import SRA_FIREWALLMANAGER_08
from sraverify.services.firewallmanager.checks.sra_firewallmanager_09 import SRA_FIREWALLMANAGER_09
from sraverify.services.firewallmanager.checks.sra_firewallmanager_10 import SRA_FIREWALLMANAGER_10

CHECKS = {
    "SRA-FIREWALLMANAGER-01": SRA_FIREWALLMANAGER_01,
    "SRA-FIREWALLMANAGER-02": SRA_FIREWALLMANAGER_02,
    "SRA-FIREWALLMANAGER-03": SRA_FIREWALLMANAGER_03,
    "SRA-FIREWALLMANAGER-04": SRA_FIREWALLMANAGER_04,
    "SRA-FIREWALLMANAGER-05": SRA_FIREWALLMANAGER_05,
    "SRA-FIREWALLMANAGER-06": SRA_FIREWALLMANAGER_06,
    "SRA-FIREWALLMANAGER-07": SRA_FIREWALLMANAGER_07,
    "SRA-FIREWALLMANAGER-08": SRA_FIREWALLMANAGER_08,
    "SRA-FIREWALLMANAGER-09": SRA_FIREWALLMANAGER_09,
    "SRA-FIREWALLMANAGER-10": SRA_FIREWALLMANAGER_10,
}
