"""Security Lake checks."""

from sraverify.services.securitylake.checks.sra_securitylake_01 import SRA_SECURITYLAKE_01
from sraverify.services.securitylake.checks.sra_securitylake_02 import SRA_SECURITYLAKE_02
from sraverify.services.securitylake.checks.sra_securitylake_03 import SRA_SECURITYLAKE_03
from sraverify.services.securitylake.checks.sra_securitylake_04 import SRA_SECURITYLAKE_04
from sraverify.services.securitylake.checks.sra_securitylake_05 import SRA_SECURITYLAKE_05
from sraverify.services.securitylake.checks.sra_securitylake_06 import SRA_SECURITYLAKE_06
from sraverify.services.securitylake.checks.sra_securitylake_07 import SRA_SECURITYLAKE_07
from sraverify.services.securitylake.checks.sra_securitylake_08 import SRA_SECURITYLAKE_08
from sraverify.services.securitylake.checks.sra_securitylake_09 import SRA_SECURITYLAKE_09
from sraverify.services.securitylake.checks.sra_securitylake_10 import SRA_SECURITYLAKE_10
from sraverify.services.securitylake.checks.sra_securitylake_11 import SRA_SECURITYLAKE_11
from sraverify.services.securitylake.checks.sra_securitylake_12 import SRA_SECURITYLAKE_12
from sraverify.services.securitylake.checks.sra_securitylake_13 import SRA_SECURITYLAKE_13
from sraverify.services.securitylake.checks.sra_securitylake_14 import SRA_SECURITYLAKE_14
from sraverify.services.securitylake.checks.sra_securitylake_15 import SRA_SECURITYLAKE_15
from sraverify.services.securitylake.checks.sra_securitylake_16 import SRA_SECURITYLAKE_16
from sraverify.services.securitylake.checks.sra_securitylake_17 import SRA_SECURITYLAKE_17

CHECKS = {
    "SRA-SECURITYLAKE-01": SRA_SECURITYLAKE_01,
    "SRA-SECURITYLAKE-02": SRA_SECURITYLAKE_02,
    "SRA-SECURITYLAKE-03": SRA_SECURITYLAKE_03,
    "SRA-SECURITYLAKE-04": SRA_SECURITYLAKE_04,
    "SRA-SECURITYLAKE-05": SRA_SECURITYLAKE_05,
    "SRA-SECURITYLAKE-06": SRA_SECURITYLAKE_06,
    "SRA-SECURITYLAKE-07": SRA_SECURITYLAKE_07,
    "SRA-SECURITYLAKE-08": SRA_SECURITYLAKE_08,
    "SRA-SECURITYLAKE-09": SRA_SECURITYLAKE_09,
    "SRA-SECURITYLAKE-10": SRA_SECURITYLAKE_10,
    "SRA-SECURITYLAKE-11": SRA_SECURITYLAKE_11,
    "SRA-SECURITYLAKE-12": SRA_SECURITYLAKE_12,
    "SRA-SECURITYLAKE-13": SRA_SECURITYLAKE_13,
    "SRA-SECURITYLAKE-14": SRA_SECURITYLAKE_14,
    "SRA-SECURITYLAKE-15": SRA_SECURITYLAKE_15,
    "SRA-SECURITYLAKE-16": SRA_SECURITYLAKE_16,
    "SRA-SECURITYLAKE-17": SRA_SECURITYLAKE_17
}
