"""Shield service checks."""

from sraverify.services.shield.checks.sra_shield_01 import SRA_SHIELD_01
from sraverify.services.shield.checks.sra_shield_02 import SRA_SHIELD_02
from sraverify.services.shield.checks.sra_shield_03 import SRA_SHIELD_03
from sraverify.services.shield.checks.sra_shield_04 import SRA_SHIELD_04
from sraverify.services.shield.checks.sra_shield_05 import SRA_SHIELD_05
from sraverify.services.shield.checks.sra_shield_06 import SRA_SHIELD_06
from sraverify.services.shield.checks.sra_shield_07 import SRA_SHIELD_07
from sraverify.services.shield.checks.sra_shield_08 import SRA_SHIELD_08
from sraverify.services.shield.checks.sra_shield_09 import SRA_SHIELD_09
from sraverify.services.shield.checks.sra_shield_10 import SRA_SHIELD_10
from sraverify.services.shield.checks.sra_shield_11 import SRA_SHIELD_11
from sraverify.services.shield.checks.sra_shield_12 import SRA_SHIELD_12
from sraverify.services.shield.checks.sra_shield_13 import SRA_SHIELD_13
from sraverify.services.shield.checks.sra_shield_14 import SRA_SHIELD_14

CHECKS = {
    "SRA-SHIELD-01": SRA_SHIELD_01,
    "SRA-SHIELD-02": SRA_SHIELD_02,
    "SRA-SHIELD-03": SRA_SHIELD_03,
    "SRA-SHIELD-04": SRA_SHIELD_04,
    "SRA-SHIELD-05": SRA_SHIELD_05,
    "SRA-SHIELD-06": SRA_SHIELD_06,
    "SRA-SHIELD-07": SRA_SHIELD_07,
    "SRA-SHIELD-08": SRA_SHIELD_08,
    "SRA-SHIELD-09": SRA_SHIELD_09,
    "SRA-SHIELD-10": SRA_SHIELD_10,
    "SRA-SHIELD-11": SRA_SHIELD_11,
    "SRA-SHIELD-12": SRA_SHIELD_12,
    "SRA-SHIELD-13": SRA_SHIELD_13,
    "SRA-SHIELD-14": SRA_SHIELD_14,
}
