from sraverify.services.account.checks.sra_account_01 import SRA_ACCOUNT_01
from sraverify.services.account.checks.sra_account_02 import SRA_ACCOUNT_02
from sraverify.services.account.checks.sra_account_03 import SRA_ACCOUNT_03

CHECKS = {
    "SRA-ACCOUNT-01": SRA_ACCOUNT_01,
    "SRA-ACCOUNT-02": SRA_ACCOUNT_02,
    "SRA-ACCOUNT-03": SRA_ACCOUNT_03,
}
